@@ -57,7 +57,6 @@
 gchar*
 xfdesktop_get_monitor_name_from_gtk_widget(GtkWidget *widget, gint monitor_num)
 {
-#if 0 /* GTK_CHECK_VERSION (3, 22, 0) */
     GdkWindow     *window = NULL;
     GdkDisplay    *display = NULL;
     GdkMonitor    *monitor = NULL;
@@ -67,12 +66,6 @@ xfdesktop_get_monitor_name_from_gtk_widget(GtkWidget *widget, gint monitor_num)
     monitor = gdk_display_get_monitor(display, monitor_num);
 
     return g_strdup(gdk_monitor_get_model(monitor));
-#else
-    GdkScreen     *screen = NULL;
-
-    screen = gtk_widget_get_screen(widget);
-    return gdk_screen_get_monitor_plug_name(screen, monitor_num);
-#endif
 }
 
 gint
@@ -218,7 +211,10 @@ create_menu_item(GtkWidget* label, GtkWidget* image)
     gtk_widget_set_halign (label, GTK_ALIGN_START);
 
     /* Add the image and label to the box, add the box to the menu item */
-    if(image && GTK_IS_WIDGET(image)) {
+    if (image && GTK_IS_WIDGET(image)) {
+        if (GTK_IS_IMAGE (image))
+            gtk_image_set_pixel_size (GTK_IMAGE (image), 16);
+
         /* only add the widget if it exists */
         gtk_widget_show (image);
 
@@ -258,6 +254,38 @@ xfdesktop_menu_create_menu_item_with_mnemonic(const gchar *name,
 
 
 
+/* Replacement for gdk_screen_width/gdk_screen_height */
+void
+xfdesktop_get_screen_dimensions (GdkScreen *screen,
+                                 gint      *width,
+                                 gint      *height)
+{
+    gint x, y, w, h;
+    GdkDisplay *display = gdk_screen_get_display(screen);
+    int num_monitors = gdk_display_get_n_monitors(display);
+
+    x = y = G_MAXINT;
+    w = h = G_MININT;
+
+    for(int i = 0; i < num_monitors; i++) {
+        GdkRectangle rect;
+        GdkMonitor *monitor = gdk_display_get_monitor(display, i);
+        gdk_monitor_get_geometry(monitor, &rect);
+
+        x = MIN(x, rect.x);
+        y = MIN(y, rect.y);
+        w = MAX(w, rect.x + rect.width);
+        h = MAX(h, rect.y + rect.height);
+    }
+
+    if(width != NULL)
+        *width = w - x;
+    if(height != NULL)
+        *height = h - y;
+}
+
+
+
 #ifdef G_ENABLE_DEBUG
 /* With --enable-debug=full turn on debugging messages from the start */
 static gboolean enable_debug = TRUE;
